* Original commands from Problem 2 of "Data Analysis Using Stata" 2016-2017 (AMSE master, M1)
* Modified on January 20, 2017 to construct sstock returns

clear

* Import and clean stock market price data
******************************************

import excel "Data\Source\8-portefeuille-cote-ape.xls", sheet("DATA") cellrange(B7:P568) allstring firstrow clear

ren B date_text
replace date_text = trim(date_text) // Some dates contain leading blanks

gen date =  date(date_text,"MDY",2050)
format date %td
drop if date == .

drop FCHI // This is not a listed firm but the code of CAC 40 stock market index

foreach var of varlist ADPPA-TCFPPA{
ren `var' price`var'
}
*

reshape long price, i(date) j(firm) string

replace firm = substr(firm,1,length(firm)-2)
tab firm

save "Data/Temp/stocks", replace

* Import and clean state's shares
*********************************

import excel "Data\Source\8-portefeuille-cote-ape.xls", sheet("DATA") cellrange(T7:AG585) allstring firstrow clear

ren T date_text
replace date_text = trim(date_text) // Some dates contain leading blanks

duplicates tag date_text, gen(A)
bro if A == 1 | A[_n+1] == 1 | A[_n-1] == 1 // Visual inspection of the data inform us that date_text is "3/25/2013" on line 140 while it should be "9/25/2013" (September instead of March)
replace date_text = "9/25/2013" if date_text == "3/25/2013" & _n == 140
drop A

gen date =  date(date_text,"MDY",2050)
format date %td
drop if date == .

foreach var of varlist ADPPA-TCFPPA{
ren `var' shares`var'
}
*

reshape long shares, i(date) j(firm) string

replace firm = substr(firm,1,length(firm)-2)
tab firm

merge 1:1 firm date using "Data/Temp/stocks"
drop _merge
erase "Data/Temp/stocks.dta"

destring shares price, replace

* Stock returns computation
***************************

egen id_firm = group(firm) // Generate set of firm identifiers

tsset id_firm date

gen return = D.price / L.price
* No returns calculated for Mondays (no available prices on Sundays) and for all days for which no price is available on the preceding day

* Computation of returns on Mondays (taking Wednesday as the preceding day)
gen return_2 = (price - L3.price) / L3.price if return == .
replace return_2 = return if return_2 == .

* Saving
********

save "Data/Final/state_stock_returns", replace
