clear

*************************************
* Analysis of AIRF and AREVA stocks *
*************************************

use "Data/Final/state_stock_returns", clear

* Summary statistics
********************

summ return if firm == "AREVA" // Average return = 0.01 %
summ return if firm == "AIRF" // Average return = 2.47 %

* Distributions
***************

* Distributions, non-edited graph
twoway kdensity return if firm == "AREVA", lcolor(red) || kdensity return if firm == "AIRF", lcolor(blue)
graph export "Output/graph_areva_airf.png", replace
graph export "Output/graph_areva_airf.eps", replace

* Distributions with means, [-0.05:0.05] focus, edited graph
summ return if firm == "AREVA"
local m_areva = r(mean)
summ return if firm == "AIRF"
local m_edf = r(mean)
twoway kdensity return if firm == "AREVA" & inrange(return,-0.05,0.05), lcolor(red) lpattern(dash) xline(`m_areva', lcolor(red) lpattern(dash)) ///
	|| kdensity return if firm == "AIRF" & inrange(return,-0.05,0.05), lcolor(blue) xline(`m_edf', lcolor(blue)) ///
	||, xtitle("Stock returns") legend(order(1 "AREVA" 2 "AIRF")) ytitle("Density") graphregion(color(white)) bgcolor(white)
graph export "Output/graph_areva_airf_clean.png", replace
graph export "Output/graph_areva_airf_clean.eps", replace

* Tests
*******

ttest return = 0 if firm == "AREVA" // P-value of "Ha: mean > 0 " is 0.46: returns are not statistically larger than 0
ttest return = 0 if firm == "AIRF" // P-value of "Ha: mean > 0" is 0.02: returns can be considered as positive at the 2% confidence level

gen areva_airf = (firm == "AREVA") if (firm =="AREVA" | firm == "AIRF")
ttest return, by(areva_airf) // P-value of equality is 0.19: returns of AREVA and AIRF cannot be considered as different

* Tests including imputed Monday's returns
******************************************

ttest return_2 = 0 if firm == "AREVA" // P-value of "Ha: mean > 0" is 0.33
ttest return_2 = 0 if firm == "AIRF" // P-value of "Ha: mean > 0" is 0.03

ttest return_2, by(areva_airf) // P-value of equality is 0.27
